@@ -4,27 +4,23 @@
 
 from __future__ import absolute_import, division, print_function
 
-import os
-import sys
-import re
 import logging
+import os
+import re
+import sys
 import traceback
-import procrunner
 from typing import Dict, Tuple  # noqa: F401
 
+import procrunner
+
 # Flake8 does not detect typing yet (https://gitlab.com/pycqa/flake8/issues/342)
 
-import dials.util.version
-
-__version__ = "0.207"
+__version__ = "0.208"
 
 logger = logging.getLogger("dials.screen19")
 debug, info, warn = logger.debug, logger.info, logger.warning
 
 
-# Check whether we need to be using DIALS v1 API
-dials_v1 = dials.util.version.dials_version().startswith("DIALS 1.")
-
 # Set axis tick positions manually.  Accounts for reciprocal(-square) d-scaling.
 d_ticks = [5, 3, 2, 1.5, 1, 0.9, 0.8, 0.7, 0.6, 0.5, 0.4]
 
@@ -47,7 +43,7 @@ def terminal_size(procrunner_debug=False):
                 print_stderr=False,
                 debug=procrunner_debug,
             )
-            rows, columns = [int(i) for i in result["stdout"].split()]
+            rows, columns = [int(i) for i in result["stdout"].decode("utf-8").split()]
         except Exception:  # ignore any errors and use default size
             pass  # FIXME: Can we be more specific about the type of exception?
     columns = min(columns, 120)
@@ -66,10 +62,14 @@ def prettyprint_dictionary(d):
     :rtype: str
     """
     return "{\n%s\n}" % "\n".join(
-        [
-            "  %s: %s" % (k, str(v).replace("\n", "\n%s" % (" " * (4 + len(k)))))
-            for k, v in d.items()
-        ]
+        "  %s: %s"
+        % (
+            k,
+            str(v.decode("latin-1") if isinstance(v, bytes) else v).replace(
+                "\n", "\n%s" % (" " * (4 + len(k)))
+            ),
+        )
+        for k, v in d.items()
     )
 
 
@@ -149,7 +149,7 @@ def plot_intensities(
     try:
         result = procrunner.run(
             command,
-            stdin="\n".join(plot_commands) + "\n",
+            stdin="\n".join(plot_commands).encode("utf-8") + b"\n",
             timeout=120,
             print_stdout=False,
             print_stderr=False,
@@ -158,13 +158,14 @@ def plot_intensities(
         )
     except OSError:
         info(traceback.format_exc())
+        result = {}
 
     debug("result = %s", prettyprint_dictionary(result))
 
     if result["exitcode"] == 0:
         star = re.compile(r"\*")
         state = set()
-        for line in result["stdout"].split("\n"):
+        for line in result["stdout"].decode("utf-8").split("\n"):
             if line.strip() != "":
                 stars = {m.start(0) for m in re.finditer(star, line)}
                 if not stars:
