@@ -26,36 +26,36 @@ The Wilson plot of I as a function of d is drawn as the file
 
 Examples:
 
-    screen19.minimum_exposure integrated_experiments.json integrated.pickle
+    screen19.minimum_exposure integrated.expt integrated.refl
 
-    screen19.minimum_exposure indexed_experiments.json indexed.pickle
+    screen19.minimum_exposure indexed.expt indexed.refl
 
     screen19.minimum_exposure min_i_over_sigma=2 desired_d=0.84 wilson_fit_max_d=4 \
-        integrated_experiments.json integrated.pickle
+        integrated.expt integrated.refl
 
 """
 
 from __future__ import absolute_import, division, print_function
 
 import logging
-import numpy as np
-from tabulate import tabulate
 import time
+from typing import Iterable, List, Optional, Sequence, Union
 
-# Flake8 does not detect typing yet (https://gitlab.com/pycqa/flake8/issues/342)
-from typing import Iterable, List, Optional, Sequence, Union  # noqa: F401
+import numpy as np
+from scipy.optimize import curve_fit
+from tabulate import tabulate
 
 import boost.python
-from cctbx import crystal, miller
+import iotbx.phil
+from cctbx import miller
+from libtbx.phil import scope, scope_extract
+
 from dials.array_family import flex
+from dials.util import log
 from dials.util.options import OptionParser
 from dials.util.version import dials_version
 from dxtbx.model import Experiment, ExperimentList
-import iotbx.phil
-from libtbx.phil import scope, scope_extract
-from scipy.optimize import curve_fit
-from screen19 import d_ticks, dials_v1, plot_intensities, terminal_size, __version__
-
+from screen19 import __version__, d_ticks, plot_intensities, terminal_size
 
 # Custom types
 FloatSequence = Sequence[float]
@@ -67,28 +67,14 @@ boost.python.floating_point_exceptions.division_by_zero_trapped = False
 help_message = __doc__
 
 
-if dials_v1:
-    verbosity_scope = u"""
-    verbosity = 1
-        .type = int(value_min=0)
-        .caption = 'The verbosity level of the command-line output'
-        .help = "Possible values:\n"
-                "\t• 0: Suppress all command-line output;\n"
-                "\t• 1: Show regular output on the command line;\n"
-                "\t• 2: Show regular output, plus detailed debugging messages."
-    """
-else:
-    verbosity_scope = u"""
+phil_scope = iotbx.phil.parse(
+    u"""
     verbosity = 0
         .type = int(value_min=0)
         .caption = 'Verbosity level of log output'
         .help = "Possible values:\n"
                 "\t• 0: Info log output to stdout/logfile\n"
                 "\t• 1: Info & debug log output to stdout/logfile"
-    """
-
-phil_scope = iotbx.phil.parse(
-    u"""
     minimum_exposure
         .caption = 'Parameters for the calculation of the lower exposure bound'
         {
@@ -127,8 +113,7 @@ phil_scope = iotbx.phil.parse(
                     "a different extension, either '.pdf', '.ps', '.eps' or '.svg', " \
                     "a file of that format will be created instead."
         }
-        """
-    + verbosity_scope,
+        """,
     process_includes=True,
 )
 
@@ -192,36 +177,23 @@ def wilson_fit(d_star_sq, intensity, sigma, wilson_fit_max_d):
     return fit
 
 
-def wilson_plot_ascii(
-    crystal_symmetry,  # type: crystal.symmetry
-    indices,  # type: Sequence[flex.miller_index, ...]
-    intensity,  # type: FloatSequence
-    sigma,  # type: FloatSequence
-    d_ticks=None,  # type: Optional[FloatSequence]
-):
-    # type: (...) -> None
+def wilson_plot_ascii(miller_array, d_ticks=None):
+    # type: (miller.array, Optional[Sequence]) -> None
     u"""
     Print an ASCII-art Wilson plot of reflection intensities.
 
     Equivalent reflections will be merged according to the crystal symmetry.
 
     Args:
-        crystal_symmetry: Crystal symmetry.
-        indices: Miller indices of reflections.
-        intensity: Intensities of reflections.
-        sigma: Standard uncertainties in reflection intensities.
+        miller_array: An array of integrated intensities, bundled with appropriate
+                      crystal symmetry and unit cell info.
         d_ticks: d location of ticks on 1/d² axis.
     """
     # Draw the Wilson plot, using existing functionality in cctbx.miller
     columns, rows = terminal_size()
-    n_bins = min(columns, intensity.size())
-    ms = miller.set(
-        crystal_symmetry=crystal_symmetry, anomalous_flag=False, indices=indices
-    )
-    ma = miller.array(ms, data=intensity, sigmas=sigma)
-    ma.set_observation_type_xray_intensity()
-    ma.setup_binner_counting_sorted(n_bins=n_bins, reflections_per_bin=1)
-    wilson = ma.wilson_plot(use_binning=True)
+    n_bins = min(columns, miller_array.data().size())
+    miller_array.setup_binner_counting_sorted(n_bins=n_bins, reflections_per_bin=1)
+    wilson = miller_array.wilson_plot(use_binning=True)
     # Get the relevant plot data from the miller_array:
     binned_intensity = [x if x else 0 for x in wilson.data[1:-1]]
     bins = dict(zip(wilson.binner.bin_centers(1), binned_intensity))
@@ -318,13 +290,38 @@ def suggest_minimum_exposure(expts, refls, params):
     refls.del_selected(refls["id"] == -1)
     # Ignore all spots flagged as overloaded
     refls.del_selected(refls.get_flags(refls.flags.overloaded).iselection())
-    # The Wilson plot fit implicitly involves taking a logarithm of
-    # intensities, so eliminate values that are going to cause problems
-    try:
-        # Work from profile-fitted intensities where possible
-        refls = refls.select(refls["intensity.prf.value"] > 0)
-    except RuntimeError:
-        refls = refls.select(refls["intensity.sum.value"] > 0)
+
+    # Work from profile-fitted intensities where possible but if the number of
+    # profile-fitted intensities is less than 75% of the number of summed
+    # intensities, use summed intensities instead.  This is a very arbitrary heuristic.
+    sel_prf = refls.get_flags(refls.flags.integrated_prf).iselection()
+    sel_sum = refls.get_flags(refls.flags.integrated_sum).iselection()
+    if sel_prf.size() < 0.75 * sel_sum.size():
+        refls = refls.select(sel_sum)
+        intensity = refls["intensity.sum.value"]
+        sigma = flex.sqrt(refls["intensity.sum.variance"])
+    else:
+        refls = refls.select(sel_prf)
+        intensity = refls["intensity.prf.value"]
+        sigma = flex.sqrt(refls["intensity.prf.variance"])
+
+    # Apply French-Wilson scaling to ensure positive intensities.
+    miller_array = miller.array(
+        miller.set(
+            expts[0].crystal.get_crystal_symmetry(),
+            refls["miller_index"],
+            anomalous_flag=False,
+        ),
+        data=intensity,
+        sigmas=sigma,
+    )
+    miller_array.set_observation_type_xray_intensity()
+    miller_array = miller_array.merge_equivalents().array()
+    miller_array = miller_array.french_wilson().as_intensity_array()
+
+    d_star_sq = miller_array.d_star_sq().data()
+    intensity = miller_array.data()
+    sigma = miller_array.sigmas()
 
     # Parameters for the lower-bound exposure estimate:
     min_i_over_sigma = params.minimum_exposure.min_i_over_sigma
@@ -340,17 +337,6 @@ def suggest_minimum_exposure(expts, refls, params):
         ]
     desired_d.sort(reverse=True)
 
-    # Get d-spacings, intensity & std dev of reflections
-    symmetry = expts[0].crystal.get_crystal_symmetry()
-    d_star_sq = 1 / symmetry.unit_cell().d(refls["miller_index"]) ** 2
-    try:
-        # Work from profile-fitted intensities and uncertainties where possible
-        intensity = refls["intensity.prf.value"]
-        sigma = flex.sqrt(refls["intensity.prf.variance"])
-    except RuntimeError:
-        intensity = refls["intensity.sum.value"]
-        sigma = flex.sqrt(refls["intensity.sum.variance"])
-
     # Perform the Wilson plot fit
     fit = wilson_fit(d_star_sq, intensity, sigma, wilson_fit_max_d)
 
@@ -368,7 +354,7 @@ def suggest_minimum_exposure(expts, refls, params):
     recommended_factor += [1]
 
     # Draw the ASCII art Wilson plot
-    wilson_plot_ascii(symmetry, refls["miller_index"], intensity, sigma, d_ticks)
+    wilson_plot_ascii(miller_array, d_ticks)
 
     recommendations = zip(desired_d, recommended_factor)
     recommendations = sorted(recommendations, key=lambda rec: rec[0], reverse=True)
@@ -396,11 +382,11 @@ def suggest_minimum_exposure(expts, refls, params):
             recommendation,
         )
 
-    summary = "\nRecommendations, summarised:\n"
+    summary = "\nRecommendations summarised:\n"
     summary += tabulate(
         recommendations,
         [u"Resolution (Å)", "Suggested\nexposure factor"],
-        floatfmt=(".2g", ".3g"),
+        floatfmt=(".3g", ".3g"),
         tablefmt="rst",
     )
     summary += (
@@ -435,7 +421,7 @@ def run(phil=phil_scope, args=None, set_up_logging=False):
         args: Arguments to parse. If None, :data:`sys.argv[1:]` will be used.
         set_up_logging: Choose whether to configure :module:`screen19` logging.
     """
-    usage = "%prog [options] experiments.json reflections.pickle"
+    usage = "%prog [options] integrated.expt integrated.refl"
 
     parser = OptionParser(
         usage=usage,
@@ -449,15 +435,8 @@ def run(phil=phil_scope, args=None, set_up_logging=False):
     params, options = parser.parse_args(args=args)
 
     if set_up_logging:
-        from dials.util import log
-
         # Configure the logging
-        if dials_v1:
-            log.config(
-                params.verbosity, info=params.output.log, debug=params.output.debug_log
-            )
-        else:
-            log.config(params.verbosity, params.output.log)
+        log.config(params.verbosity, params.output.log)
 
     if not (params.input.experiments and params.input.reflections):
         version_information = "screen19.minimum_exposure v%s using %s (%s)" % (
